==> jbossws-cxf-server-3.3.0.GA-sources.jar: org/jboss/wsf/stack/cxf/security/authentication/AuthenticationManagerLoader.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.stack.cxf.security.authentication;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.jboss.security.AuthenticationManager;

/**
 * AuthenticationManager loader
 * 
 * @author Sergey Beryozkin
 *
 */
public class AuthenticationManagerLoader
{
   public AuthenticationManager getManager()
   {
      try
      {
         Context ctx = new InitialContext();
         Object obj = ctx.lookup("java:/comp/env/security/securityMgr");
         return (AuthenticationManager)obj;
      }
      catch (NamingException ne)
      {
         throw new SecurityException("Unable to lookup AuthenticationManager");
      }
   }
}

==> jbossws-cxf-server-3.3.1.GA-sources.jar: org/jboss/wsf/stack/cxf/security/authentication/AuthenticationManagerLoader.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.stack.cxf.security.authentication;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.jboss.security.AuthenticationManager;
import org.picketbox.factories.SecurityFactory;

/**
 * AuthenticationManager loader
 * 
 * @author Sergey Beryozkin
 *
 */
public class AuthenticationManagerLoader
{
   public AuthenticationManager getManagerWithJndi()
   {
      try
      {
         Context ctx = new InitialContext();
         Object obj = ctx.lookup("java:/comp/env/security/securityMgr");
         return (AuthenticationManager)obj;
      }
      catch (NamingException ne)
      {
         throw new SecurityException("Unable to lookup AuthenticationManager using JNDI");
      }
   }
   
   public AuthenticationManager getManager(String securityDomainName)
   {
      SecurityFactory.prepare();
      try
      { 
    	 return SecurityFactory.getAuthenticationManager(securityDomainName);
      }
      catch (Exception ex) {
         throw new SecurityException("Unable to get Authentication Manager", ex);
      }
      finally 
      {
         SecurityFactory.release();
      }
   }
   
}
